﻿#WORKUNIT('name', 'FDA_Drugs - ETL');
import std;
import FDA_Drugs;
// Name:	Eric Bales
// Email: eric.bales@lnssi.com
//
// Data Source: http://www.fda.gov/Drugs/InformationOnDrugs/ucm079750.htm
//
// Instructions:
// 1. Download zip file containing the data from the URL above.
//		The layout of the data is also documented at this same URL.
// 2. Unzip the contents of the file (9 delimited-text files) to a local folder.
//		Examine the contents of the files to see what's in there, and how it's laid out.
// 3. Transfer the txt files to the Landing Zone.
// 4. Set the IP address for the Landing Zone here:
LandingZone_IP := '10.220.5.57';
// 5. Set the folder containing the data files on the Landing Zone here:  (Should end in / )
BaseDataDirectory := '/ftp/in/FDA_Drugs/';
// 6. Execute this BWR.  It will read the data from the Landing Zone and ingest it into the system.
//

// This BWR ingests the FDA Drug data from the landing zone.

// Filenames for the raw files on the landing zone, including path.
Raw_AppDoc := 							BaseDataDirectory+'AppDoc.txt';
Raw_AppDocType_Lookup :=		BaseDataDirectory+'AppDocType_Lookup.txt';
Raw_Application := 					BaseDataDirectory+'Application.txt';
Raw_DocType_Lookup :=				BaseDataDirectory+'DocType_lookup.txt';
Raw_Product :=							BaseDataDirectory+'Product.txt';
Raw_Product_TECode :=				BaseDataDirectory+'Product_tecode.txt';
Raw_RegActionDate :=				BaseDataDirectory+'RegActionDate.txt';
Raw_ChemicalType_Lookup :=	BaseDataDirectory+'ChemTypeLookup.txt';
Raw_ReviewClass_Lookup :=		BaseDataDirectory+'ReviewClass_Lookup.txt';

// For all data files, the input data is in text delimited format with tab as the
// delimiter, 1 heading row, and no quotes.

// Ingest, distribute, and write out AppDoc
dsAppDoc_In := DATASET(std.File.ExternalLogicalFilename(LandingZone_IP,Raw_AppDoc),
		FDA_Drugs.Layouts.L_AppDoc,
		CSV(HEADING(1), SEPARATOR('\t'), TERMINATOR(['\r\n','\n\r','\n','\r']), QUOTE(''), ASCII) );
dsAppDoc := DISTRIBUTE(dsAppDoc_In, AppDocID);
OUTPUT(dsAppDoc,, FDA_Drugs.Datasets.File_AppDoc, overwrite);


// Ingest, distribute, and write out AppDocType_Lookup
dsAppDocType_Lookup_In := DATASET(std.File.ExternalLogicalFilename(LandingZone_IP,Raw_AppDocType_Lookup),
		FDA_Drugs.Layouts.L_AppDocType_Lookup,
		CSV(HEADING(1), SEPARATOR('\t'), TERMINATOR(['\r\n','\n\r','\n','\r']), QUOTE(''), ASCII) );
dsAppDocType_Lookup := DISTRIBUTE(dsAppDocType_Lookup_In, HASH(AppDocType));
OUTPUT(dsAppDocType_Lookup,, FDA_Drugs.Datasets.File_AppDocType_Lookup, overwrite);


// Ingest, distribute, and write out Application
//  The Boolean values are stored as strings in the raw data - have to convert them
L_Application_Raw := RECORD
		STRING6		ApplNo;
		STRING5		ApplType;
		STRING50	SponsorApplicant;
		STRING5		MostRecentLabelAvailableFlag; // Boolean
		STRING5		CurrentPatentFlag;						// Boolean
		STRING10	ActionType;
		STRING3		ChemicalType;
		STRING2		TherapeuticPotential;
		STRING1		OrphanCode;
END;
dsApplication_In := DATASET(std.File.ExternalLogicalFilename(LandingZone_IP,Raw_Application),
		L_Application_Raw,
		CSV(HEADING(1), SEPARATOR('\t'), TERMINATOR(['\r\n','\n\r','\n','\r']), QUOTE(''), ASCII) );
dsApplication_Convert :=
	PROJECT(dsApplication_In,
					TRANSFORM(FDA_Drugs.Layouts.L_Application,
										SELF.MostRecentLabelAvailableFlag := IF(LEFT.MostRecentLabelAvailableFlag='False',False,True);
										SELF.CurrentPatentFlag := IF(LEFT.CurrentPatentFlag='False',False,True);
										SELF := LEFT;));
dsApplication := DISTRIBUTE(dsApplication_Convert, HASH(ApplNo));
OUTPUT(dsApplication,, FDA_Drugs.Datasets.File_Application, overwrite);


// Ingest, distribute, and write out DocType_Lookup
dsDocType_Lookup_In := DATASET(std.File.ExternalLogicalFilename(LandingZone_IP,Raw_DocType_Lookup),
		FDA_Drugs.Layouts.L_DocType_Lookup,
		CSV(HEADING(1), SEPARATOR('\t'), TERMINATOR(['\r\n','\n\r','\n','\r']), QUOTE(''), ASCII) );
dsDocType_Lookup := DISTRIBUTE(dsDocType_Lookup_In, HASH(DocType));
OUTPUT(dsDocType_Lookup,, FDA_Drugs.Datasets.File_DocType_Lookup, overwrite);


// Ingest, distribute, and write out Product
//  The Boolean values are stored as strings in the raw data - have to convert them
L_Product_Raw := RECORD
		STRING6		ApplNo;
		STRING3		ProductNo;
		STRING255	Form;
		STRING240	Dosage;
		UNSIGNED1	ProductMktStatus;
		STRING100	TECode;
		STRING5		ReferenceDrug;  // Boolean
		STRING125	DrugName;
		STRING255	ActiveIngred;
END;
dsProduct_In := DATASET(std.File.ExternalLogicalFilename(LandingZone_IP,Raw_Product),
		L_Product_Raw,
		CSV(HEADING(1), SEPARATOR('\t'), TERMINATOR(['\r\n','\n\r','\n','\r']), QUOTE(''), ASCII) );
dsProduct_Convert :=
	PROJECT(dsProduct_In,
					TRANSFORM(FDA_Drugs.Layouts.L_Product,
										SELF.ReferenceDrug := IF(LEFT.ReferenceDrug='False',False,True);
										SELF := LEFT;));
dsProduct := DISTRIBUTE(dsProduct_Convert, HASH(ApplNo));
OUTPUT(dsProduct,, FDA_Drugs.Datasets.File_Product, overwrite);


// Ingest, distribute, and write out Product_TECode
dsProduct_TECode_In := DATASET(std.File.ExternalLogicalFilename(LandingZone_IP,Raw_Product_TECode),
		FDA_Drugs.Layouts.L_Product_TECode,
		CSV(HEADING(1), SEPARATOR('\t'), TERMINATOR(['\r\n','\n\r','\n','\r']), QUOTE(''), ASCII) );
dsProduct_TECode := DISTRIBUTE(dsProduct_TECode_In, HASH(ApplNo));
OUTPUT(dsProduct_TECode,, FDA_Drugs.Datasets.File_Product_TECode, overwrite);


// Ingest, distribute, and write out RegActionDate
dsRegActionDate_In := DATASET(std.File.ExternalLogicalFilename(LandingZone_IP,Raw_RegActionDate),
		FDA_Drugs.Layouts.L_RegActionDate,
		CSV(HEADING(1), SEPARATOR('\t'), TERMINATOR(['\r\n','\n\r','\n','\r']), QUOTE(''), ASCII) );
dsRegActionDate := DISTRIBUTE(dsRegActionDate_In, HASH(ApplNo));
OUTPUT(dsRegActionDate,, FDA_Drugs.Datasets.File_RegActionDate, overwrite);


// Ingest, distribute, and write out ChemicalType_Lookup
dsChemicalType_Lookup_In := DATASET(std.File.ExternalLogicalFilename(LandingZone_IP,Raw_ChemicalType_Lookup),
		FDA_Drugs.Layouts.L_ChemicalType_Lookup,
		CSV(HEADING(1), SEPARATOR('\t'), TERMINATOR(['\r\n','\n\r','\n','\r']), QUOTE(''), ASCII) );
dsChemicalType_Lookup := DISTRIBUTE(dsChemicalType_Lookup_In, ChemicalTypeID);
OUTPUT(dsChemicalType_Lookup,, FDA_Drugs.Datasets.File_ChemicalType_Lookup, overwrite);


// Ingest, distribute, and write out ReviewClass_Lookup
dsReviewClass_Lookup_In := DATASET(std.File.ExternalLogicalFilename(LandingZone_IP,Raw_ReviewClass_Lookup),
		FDA_Drugs.Layouts.L_ReviewClass_Lookup,
		CSV(HEADING(1), SEPARATOR('\t'), TERMINATOR(['\r\n','\n\r','\n','\r']), QUOTE(''), ASCII) );
dsReviewClass_Lookup := DISTRIBUTE(dsReviewClass_Lookup_In, ReviewClassID);
OUTPUT(dsReviewClass_Lookup,, FDA_Drugs.Datasets.File_ReviewClass_Lookup, overwrite);
