﻿EXPORT Layouts := MODULE

	// Application Documents
	//  Document addresses or URLs to letters, labels, reviews, Consumer Information Sheets,
	//  FDA Talk Papers, and other types.
	EXPORT L_AppDoc := RECORD
		INTEGER4		AppDocID;
		STRING6			ApplNo;
		STRING4			SeqNo;
		STRING50		DocType;
		STRING100		DocTitle;
		STRING200		DocURL;
		STRING19		DocDate;
		STRING10		ActionType;
		INTEGER4		DuplicateCounter;
	END;

	// Application Document Type Lookup
	//  Type of document that is linked, which relates to the AppDoc record.
	EXPORT L_AppDocType_Lookup := RECORD
		STRING50		AppDocType;
		INTEGER4		SortOrder;
	END;

	// Application
	//  Application number and sponsor name.
	EXPORT L_Application := RECORD
		STRING6		ApplNo;
		STRING5		ApplType;
		STRING50	SponsorApplicant;
		BOOLEAN		MostRecentLabelAvailableFlag;
		BOOLEAN		CurrentPatentFlag;
		STRING10	ActionType;
		STRING3		ChemicalType;
		STRING2		TherapeuticPotential;
		STRING1		OrphanCode;
	END;
	
	// Document Type Lookup
	//  Supplement type code and description to the application number.
	EXPORT L_DocType_Lookup := RECORD
		STRING4		DocType;
		STRING50	DocTypeDesc;
	END;
	
	// Product
	//  This table contains the products included in each application. Includes form, dosage,
	//  and route.
	EXPORT L_Product := RECORD
		STRING6		ApplNo;
		STRING3		ProductNo;
		STRING255	Form;
		STRING240	Dosage;
		UNSIGNED1	ProductMktStatus;  // (1=prescription, 2=OTC, 3=discontinued, 4=tentative approval)
		STRING100	TECode;
		BOOLEAN		ReferenceDrug;
		STRING125	DrugName;
		STRING255	ActiveIngred;
	END;

	// Product TECode
	//  Therapeutic Equivalence Code for products.
	EXPORT L_Product_TECode := RECORD
		STRING6		ApplNo;
		STRING3		ProductNo;
		STRING50	TECode;
		INTEGER4	TESequence;
		UNSIGNED1	ProductMktStatus;
	END;

	// Supplements (Regulatory Action Date)
	//  Approval history for each application. Includes supplement number and dates of approval.
	EXPORT L_RegActionDate := RECORD
		STRING6		ApplNo;
		STRING10	ActionType;
		STRING4		InDocTypeSeqNo;
		INTEGER4	DuplicateCounter;
		STRING19	ActionDate;
		STRING4		DocType;
	END;
	
	// Chemical Type Lookup
	EXPORT L_ChemicalType_Lookup := RECORD
		INTEGER4	ChemicalTypeID;
		STRING3		ChemicalTypeCode;
		STRING200	ChemicalTypeDescription;
	END;

	// Review Class Lookup
	EXPORT L_ReviewClass_Lookup := RECORD
		INTEGER4	ReviewClassID;
		STRING1		ReviewCode;
		STRING100	LongDescription;
		STRING100	ShortDescription;
	END;

END;
